@@ -187,7 +187,6 @@ MainWindow::init()
     connect( engine(), SIGNAL( titleChanged( const QString& ) ), this, SLOT( setCaption( const QString& ) ) );
     connect( engine(), SIGNAL( subChannelsChanged( QList< QAction* > ) ), this, SLOT( subChannelsChanged( QList< QAction* > ) ) );
     connect( engine(), SIGNAL( audioChannelsChanged( QList< QAction* > ) ), this, SLOT( audioChannelsChanged( QList< QAction* > ) ) );
-    connect( engine(), SIGNAL( mutedChanged( bool ) ), this, SLOT( mutedChanged( bool ) ) );
 
     if( !engine()->init() ) {
         KMessageBox::error( this, i18n(
@@ -341,13 +340,6 @@ MainWindow::toggleVolumeSlider( bool show )
     }
 }
 
-void
-MainWindow::mutedChanged( bool mute )
-{
-    if( m_volumeSlider )
-        m_volumeSlider->setDisabled ( mute );
-}
-
 void
 MainWindow::updateSliders()
 {
